@@ -26,7 +26,9 @@ which_sfc_col = function(cls) {
 		MULTIPOLYGON = 3,
 		MULTICURVE = 3,
 		GEOMETRYCOLLECTION = 4,
+		COMPOUNDCURVE = 4,
 		MULTISURFACE = 4,
+		CURVEPOLYGON = 4,
 		GEOMETRY = 5,
 		stop(paste("st_cast for", cls, "not supported"))
 	)
@@ -120,7 +122,7 @@ st_cast_sfc_default = function(x) {
 			x <- lapply(x, function(x) if (inherits(x, "POLYGON")) POLYGON2MULTIPOLYGON(x) else x)
 			class(x) <- c("sfc_MULTIPOLYGON", "sfc")
 		}
-	} else if (cls == "GEOMETRYCOLLECTION" && !any(st_is_empty(x))) { # FIXME: do sth better in case of empty?
+	} else if (cls == "GEOMETRYCOLLECTION" && all(lengths(x))) { # https://github.com/r-spatial/sf/issues/1767
 		ids = get_lengths(x)
 		x <- do.call(st_sfc, unlist(x, recursive = FALSE))
 	}
@@ -130,9 +132,32 @@ st_cast_sfc_default = function(x) {
 
 copy_sfc_attributes_from = function(x, ret) {
 	structure(ret, precision = attr(x, "precision"),
-		bbox = attr(x, "bbox"), crs = attr(x, "crs"), n_empty = attr(x, "n_empty"))
+		bbox = attr(x, "bbox"), crs = attr(x, "crs"), n_empty = attr(x, "n_empty"), 
+		z_range = attr(x, "z_range"), m_range = attr(x, "m_range"))
 }
 
+empty_sfg <- function(to) {
+	switch(to,
+		   GEOMETRYCOLLECTION = st_geometrycollection(),
+		   MULTIPOLYGON = st_multipolygon(),
+		   POLYGON = st_polygon(),
+		   MULTILINESTRING = st_multilinestring(),
+		   LINESTRING = st_linestring(),
+		   MULTIPOINT = st_multipoint(),
+		   POINT = st_point()
+	   )
+}
+
+is_exotic = function(x) {
+	stopifnot(length(x) > 0)
+	if (inherits(x, c("sfc_MULTICURVE", "sfc_COMPOUNDCURVE", "sfc_CURVEPOLYGON", "sfc_MULTISURFACE"))) # for which GEOS has no st_is_empty()
+		TRUE
+	else if (inherits(x, "sfc_GEOMETRY")) {
+		cls = sapply(x, class)
+		any(cls[2,] %in% c("MULTICURVE", "COMPOUNDCURVE", "CURVEPOLYGON", "MULTISURFACE"))
+	} else
+		FALSE
+}
 
 #' @name st_cast
 #' @param ids integer vector, denoting how geometries should be grouped (default: no grouping)
@@ -140,15 +165,34 @@ copy_sfc_attributes_from = function(x, ret) {
 #' @param ... ignored
 #' @export
 #' @return In case \code{to} is missing, \code{st_cast.sfc} will coerce combinations of "POINT" and "MULTIPOINT", "LINESTRING" and "MULTILINESTRING", "POLYGON" and "MULTIPOLYGON" into their "MULTI..." form, or in case all geometries are "GEOMETRYCOLLECTION" will return a list of all the contents of the "GEOMETRYCOLLECTION" objects, or else do nothing. In case \code{to} is specified, if \code{to} is "GEOMETRY", geometries are not converted, else, \code{st_cast} will try to coerce all elements into \code{to}; \code{ids} may be specified to group e.g. "POINT" objects into a "MULTIPOINT", if not specified no grouping takes place. If e.g. a "sfc_MULTIPOINT" is cast to a "sfc_POINT", the objects are split, so no information gets lost, unless \code{group_or_split} is \code{FALSE}.
-#'
+#' @details When converting a GEOMETRYCOLLECTION to COMPOUNDCURVE, MULTISURFACE or CURVEPOLYGON, the user is responsible for the validity of the resulting object: no checks are being carried out by the software.
+#' 
+#' When converting mixed, GEOMETRY sets, it may help to first convert to the MULTI-type, see examples
+#' @examples
+#' # https://github.com/r-spatial/sf/issues/1930:
+#' pt1 <- st_point(c(0,1))
+#' pt23 <- st_multipoint(matrix(c(1,2,3,4), ncol = 2, byrow = TRUE))
+#' d <- st_sf(geom = st_sfc(pt1, pt23))
+#' st_cast(d, "POINT") # will not convert the entire MULTIPOINT, and warns
+#' st_cast(d, "MULTIPOINT") %>% st_cast("POINT")
 st_cast.sfc = function(x, to, ..., ids = seq_along(x), group_or_split = TRUE) {
-	if (missing(to))
+	if (missing(to) || length(x) == 0)
 		return(st_cast_sfc_default(x))
 
+	e = rep(FALSE, length(x))
+	if (!is_exotic(x)) { # for which GEOS has no st_is_empty()
+		e = st_is_empty(x)
+		if (all(e)) {
+			x[e] = empty_sfg(to)
+			return(x) # RETURNS
+		}
+	}
+	if (any(e))
+		x = x[!e]
 	from_cls = substr(class(x)[1], 5, 100)
 	from_col = which_sfc_col(from_cls)
 	to_col = which_sfc_col(to)
-	if (from_cls == to)
+	ret = if (from_cls == to)
 		x # returns x: do nothing
 	else if (to == "GEOMETRY") # we can always do that:
 		structure(x, class = c("sfc_GEOMETRY", "sfc"))
@@ -198,6 +242,14 @@ st_cast.sfc = function(x, to, ..., ids = seq_along(x), group_or_split = TRUE) {
 		# EJP: FIXME:
 		structure(reclass(ret, to, need_close(to)), ids = get_lengths(x))
 	}
+	if (any(e)) {
+		crs = st_crs(x)
+		x = vector("list", length = length(e))
+		x[e] = list(empty_sfg(to))
+		x[!e] = ret
+		st_set_crs(do.call(st_sfc, x), crs)
+	} else
+		ret
 }
 
 #' @name st_cast
@@ -207,7 +259,6 @@ st_cast.sfc = function(x, to, ..., ids = seq_along(x), group_or_split = TRUE) {
 #' @details the \code{st_cast} method for \code{sf} objects can only split geometries, e.g. cast \code{MULTIPOINT} into multiple \code{POINT} features.  In case of splitting, attributes are repeated and a warning is issued when non-constant attributes are assigned to sub-geometries. To merge feature geometries and attribute values, use \link[sf:aggregate.sf]{aggregate} or \link[sf:tidyverse]{summarise}.
 st_cast.sf = function(x, to, ..., warn = TRUE, do_split = TRUE) {
 	geom = st_cast(st_geometry(x), to, group_or_split = do_split)
-	crs = st_crs(x)
 	agr = st_agr(x)
 	all_const = all_constant(x)
 	sf_column = attr(x, "sf_column") # keep name
