@@ -1,3 +1,15 @@
+st_datum = function(x) {
+	stopifnot(inherits(x, c("crs", "sf", "sfc")))
+	if (inherits(x, "crs"))
+		x = st_sfc(st_point(), crs = x)
+	x = st_geometry(x) # in case inherits(x, "sf")
+	datum = st_crs(st_crs(x, parameters = TRUE)$gcs_crs)
+	if (is.na(datum))
+		st_crs('OGC:CRS84') # + message or warning?
+	else
+		datum
+}
+
 #' Compute graticules and their parameters
 #'
 #' Compute graticules and their parameters
@@ -15,9 +27,9 @@
 #' @export
 #' @param x object of class \code{sf}, \code{sfc} or \code{sfg} or numeric vector with bounding box given as (minx, miny, maxx, maxy).
 #' @param crs object of class \code{crs}, with the display coordinate reference system
-#' @param datum either an object of class \code{crs} with the coordinate reference system for the graticules, or \code{NULL} in which case a grid in the coordinate system of \code{x} is drawn, or \code{NA}, in which case an empty \code{sf} object is returned.
-#' @param lon numeric; degrees east for the meridians
-#' @param lat numeric; degrees north for the parallels
+#' @param datum either an object of class \code{crs} with the coordinate reference system for the graticules, or \code{NULL} in which case a grid in the coordinate system of \code{x} is drawn, or \code{NA}, in which case an empty \code{sf} object is returned. If missing and \code{x} has a crs with a datum, the geographic coordinate system (datum) of \code{x} is taken.
+#' @param lon numeric; values in degrees East for the meridians, associated with \code{datum}
+#' @param lat numeric; values in degrees North for the parallels, associated with \code{datum}
 #' @param ndiscr integer; number of points to discretize a parallel or meridian
 #' @param margin numeric; small number to trim a longlat bounding box that touches or
 #'  crosses +/-180 long or +/-90 latitude.
@@ -27,7 +39,7 @@
 #' see example.
 #' @examples
 #' library(sf)
-#' library(maps)
+#' if (require(maps, quietly = TRUE)) {
 #'
 #' usa = st_as_sf(map('usa', plot = FALSE, fill = TRUE))
 #' laea = st_crs("+proj=laea +lat_0=30 +lon_0=-95") # Lambert equal area
@@ -38,7 +50,7 @@
 #'    c( bb[3],bb[4]),c( bb[1],bb[4]),c( bb[1],bb[2])))
 #'
 #' g = st_graticule(usa)
-#' plot(usa, xlim = 1.2 * c(-2450853.4, 2186391.9))
+#' plot(usa, xlim = 1.2 * c(-2450853.4, 2186391.9), reset = FALSE)
 #' plot(g[1], add = TRUE, col = 'grey')
 #' plot(bbox, add = TRUE)
 #' points(g$x_start, g$y_start, col = 'red')
@@ -46,29 +58,39 @@
 #'
 #' invisible(lapply(seq_len(nrow(g)), function(i) {
 #'	if (g$type[i] == "N" && g$x_start[i] - min(g$x_start) < 1000)
-#'		text(g[i,"x_start"], g[i,"y_start"], labels = parse(text = g[i,"degree_label"]),
+#'		text(g$x_start[i], g$y_start[i], labels = parse(text = g$degree_label[i]), 
 #'			srt = g$angle_start[i], pos = 2, cex = .7)
 #'	if (g$type[i] == "E" && g$y_start[i] - min(g$y_start) < 1000)
-#'		text(g[i,"x_start"], g[i,"y_start"], labels = parse(text = g[i,"degree_label"]),
+#'		text(g$x_start[i], g$y_start[i], labels = parse(text = g$degree_label[i]), 
 #'			srt = g$angle_start[i] - 90, pos = 1, cex = .7)
 #'	if (g$type[i] == "N" && g$x_end[i] - max(g$x_end) > -1000)
-#'		text(g[i,"x_end"], g[i,"y_end"], labels = parse(text = g[i,"degree_label"]),
+#'		text(g$x_end[i], g$y_end[i], labels = parse(text = g$degree_label[i]), 
 #'			srt = g$angle_end[i], pos = 4, cex = .7)
 #'	if (g$type[i] == "E" && g$y_end[i] - max(g$y_end) > -1000)
-#'		text(g[i,"x_end"], g[i,"y_end"], labels = parse(text = g[i,"degree_label"]),
+#'		text(g$x_end[i], g$y_end[i], labels = parse(text = g$degree_label[i]), 
 #'			srt = g$angle_end[i] - 90, pos = 3, cex = .7)
 #' }))
 #' plot(usa, graticule = st_crs(4326), axes = TRUE, lon = seq(-60,-130,by=-10))
-st_graticule = function(x = c(-180,-90,180,90), crs = st_crs(x),
-	datum = st_crs(4326), ..., lon = NULL, lat = NULL, ndiscr = 100,
+#' }
+st_graticule = function(x = c(-180, -90, 180, 90), crs = st_crs(x),
+	datum = st_crs('OGC:CRS84'), ..., lon = NULL, lat = NULL, ndiscr = 100,
 	margin = 0.001)
 {
+	s2 = sf_use_s2()
+	on.exit(suppressMessages(sf_use_s2(s2)))
+	suppressMessages(sf_use_s2(FALSE))
+
 	if (missing(x)) {
 		crs = datum
 		if (is.null(lon))
 			lon = seq(-180, 180, by = 20)
 		if (is.null(lat))
 			lat = seq(-80, 80, by = 20)
+	} else if (missing(datum)) {
+		datum = if (inherits(x, c("sf", "sfc")))
+				st_datum(x)
+			else
+				st_datum(crs)
 	}
 
 	if (is.null(crs))
@@ -85,7 +107,7 @@ st_graticule = function(x = c(-180,-90,180,90), crs = st_crs(x),
 		st_bbox(x)
 	else
 		x
-	stopifnot(is.numeric(bb) && length(bb) == 4)
+	stopifnot(is.numeric(bb), length(bb) == 4)
 
 	if (isTRUE(st_is_longlat(crs)))
 		bb = trim_bb(bb, margin)
@@ -201,7 +223,7 @@ graticule_attributes = function(df) {
 }
 
 trim_bb = function(bb = c(-180, -90, 180, 90), margin, wrap=c(-180,180)) {
-	stopifnot(margin > 0 && margin <= 1.0)
+	stopifnot(margin > 0, margin <= 1.0)
 	fr = 1.0 - margin
 	if (min(bb[c(1,3)]) >= -15. && max(bb[c(1,3)]) > 195.) { # 0-360 span:
 		wrap=c(0., 360.)
