@@ -76,20 +76,21 @@ st_join = function(x, y, join, ...) UseMethod("st_join")
 #' 
 #' @details alternative values for argument \code{join} are:
 #' \itemize{
-#'   \item \link{st_contains_properly}
-#'   \item \link{st_contains}
-#'   \item \link{st_covered_by}
-#'   \item \link{st_covers}
-#'   \item \link{st_crosses}
-#'   \item \link{st_disjoint}
-#'   \item \link{st_equals_exact}
-#'   \item \link{st_equals}
-#'   \item \link{st_is_within_distance}
-#'   \item \link{st_nearest_feature}
-#'   \item \link{st_overlaps}
-#'   \item \link{st_touches}
-#'   \item \link{st_within}
-#'   \item any user-defined function of the same profile as the above
+#'   \item \link{st_contains_properly},
+#'   \item \link{st_contains},
+#'   \item \link{st_covered_by},
+#'   \item \link{st_covers},
+#'   \item \link{st_crosses},
+#'   \item \link{st_disjoint},
+#'   \item \link{st_equals_exact},
+#'   \item \link{st_equals},
+#'   \item \link{st_is_within_distance},
+#'   \item \link{st_nearest_feature},
+#'   \item \link{st_overlaps},
+#'   \item \link{st_touches},
+#'   \item \link{st_within},
+#'   \item \link{st_relate} (which will require `pattern` to be set),
+#'   \item or any user-defined function of the same profile as the above
 #' }
 #' A left join returns all records of the \code{x} object with \code{y} fields for non-matched records filled with \code{NA} values; an inner join returns only records that spatially match.
 #' 
@@ -127,6 +128,10 @@ st_join = function(x, y, join, ...) UseMethod("st_join")
 #' text(st_coordinates(st_centroid(nc_j)), labels = nc_j$label, cex = .8)
 #' plot(st_geometry(gr), border = 'green', add = TRUE)
 #' par(opar)
+#' # st_filter keeps the geometries in x where .predicate(x,y) returns any match in y for x
+#' st_filter(a, b)
+#' # for an anti-join, use the union of y
+#' st_filter(a, st_union(b), .predicate = st_disjoint)
 #' @export
 st_join.sf = function(x, y, join = st_intersects, ..., suffix = c(".x", ".y"), 
 		left = TRUE, largest = FALSE) {
@@ -170,7 +175,7 @@ st_join.sf = function(x, y, join = st_intersects, ..., suffix = c(".x", ".y"),
 	if (inherits(x, "tbl_df") && requireNamespace("dplyr", quietly = TRUE))
 		st_sf(dplyr::bind_cols(x[ix,], y[unlist(i), , drop = FALSE]))
   	else
-		st_sf(cbind(as.data.frame(x)[ix,], y[unlist(i), , drop = FALSE]))	
+		st_sf(cbind(as.data.frame(x)[ix, ,drop=FALSE], y[unlist(i), , drop = FALSE]))
 }
 
 #' @export
@@ -184,5 +189,5 @@ st_filter.sf = function(x, y, ..., .predicate = st_intersects) {
 	if (!requireNamespace("dplyr", quietly = TRUE))
 		stop("dplyr is not installed: install first?")
 
-    dplyr::filter(x, lengths(.predicate(x, y, ...)) > 0) # will call filter.sf
+    dplyr::filter(x, lengths(.predicate(!!x, !!y, ...)) > 0) # will call filter.sf
 }
