@@ -1,10 +1,14 @@
 #include <iostream>
 
 #include <ogr_srs_api.h>
+#include <cpl_string.h>
 
 #include "Rcpp.h"
 
-// [[Rcpp::export]]
+#define NO_GDAL_CPP_HEADERS
+#include "gdal_sf_pkg.h"
+
+// [[Rcpp::export(rng=false)]]
 Rcpp::LogicalVector CPL_proj_h(bool b = false) {
 #if defined(HAVE_PROJ_H) && !defined(ACCEPT_USE_OF_DEPRECATED_PROJ_API_H)
 	return true;
@@ -26,7 +30,7 @@ Rcpp::LogicalVector CPL_proj_h(bool b = false) {
 # endif
 #endif
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::DataFrame CPL_get_pipelines(Rcpp::CharacterVector crs, Rcpp::CharacterVector authority, 
 		Rcpp::NumericVector AOI, Rcpp::CharacterVector Use, 
 		Rcpp::CharacterVector grid_availability,
@@ -180,12 +184,24 @@ Rcpp::DataFrame CPL_get_pipelines(Rcpp::CharacterVector crs, Rcpp::CharacterVect
 #endif
 }
 
-// [[Rcpp::export]]
-Rcpp::CharacterVector CPL_get_data_dir(bool b = false) {
-	return Rcpp::CharacterVector(proj_info().searchpath);
+// [[Rcpp::export(rng=false)]]
+Rcpp::CharacterVector CPL_get_data_dir(bool from_proj = false) {
+	if (from_proj) {
+		Rcpp::CharacterVector ret(proj_info().searchpath);
+		return ret;
+	} else {
+#if GDAL_VERSION_NUM >= 3000300
+		char **ogr_sp = OSRGetPROJSearchPaths();
+		Rcpp::CharacterVector ogr_sp_sf = charpp2CV(ogr_sp);
+		CSLDestroy(ogr_sp);
+		return ogr_sp_sf;
+#else
+		Rcpp::stop("requires GDAL >= 3.0.3");
+#endif
+	}
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::LogicalVector CPL_is_network_enabled(bool b = false) {
 #if PROJ_VERSION_MAJOR >= 7
 #if GDAL_VERSION_NUM >= 3040000
@@ -198,7 +214,7 @@ Rcpp::LogicalVector CPL_is_network_enabled(bool b = false) {
 #endif
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::CharacterVector CPL_enable_network(Rcpp::CharacterVector url, bool enable = true) {
 #ifdef HAVE_71
 	if (enable) {
@@ -221,20 +237,32 @@ Rcpp::CharacterVector CPL_enable_network(Rcpp::CharacterVector url, bool enable
 #endif
 }
 
-// [[Rcpp::export]]
-Rcpp::LogicalVector CPL_set_data_dir(std::string data_dir) {
-	const char *cp = data_dir.c_str();
-	proj_context_set_search_paths(PJ_DEFAULT_CTX, 1, &cp);
+// [[Rcpp::export(rng=false)]]
+Rcpp::LogicalVector CPL_set_data_dir(Rcpp::CharacterVector data_dir, bool with_proj) {
+	if (with_proj) {
+		if (data_dir.size() != 1)
+			Rcpp::stop("data_dir should be size 1 character vector"); // #nocov
+		std::string dd = Rcpp::as<std::string>(data_dir);
+		const char *cp = dd.c_str();
+		proj_context_set_search_paths(PJ_DEFAULT_CTX, 1, &cp);
+	} else {
+#if GDAL_VERSION_NUM >= 3000000
+		std::vector <char *> dirs = create_options(data_dir, true);
+		OSRSetPROJSearchPaths(dirs.data());
+#else
+		Rcpp::stop("setting proj search path for GDAL requires GDAL >= 3.0.0");
+#endif
+	}
 	return true;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::LogicalVector CPL_use_proj4_init_rules(Rcpp::IntegerVector v) {
 	proj_context_use_proj4_init_rules(PJ_DEFAULT_CTX, v[0]);
 	return true;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 std::string CPL_proj_version(bool b = false) {
 
 	std::stringstream buffer;
@@ -242,7 +270,7 @@ std::string CPL_proj_version(bool b = false) {
 	return buffer.str();
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_proj_is_valid(std::string proj4string) {
 	Rcpp::List out(2);
 
@@ -261,7 +289,7 @@ Rcpp::List CPL_proj_is_valid(std::string proj4string) {
 	return out;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 bool CPL_have_datum_files(SEXP foo) {
 
 	// TODO:
@@ -270,7 +298,7 @@ bool CPL_have_datum_files(SEXP foo) {
 	return true;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::NumericMatrix CPL_proj_direct(Rcpp::CharacterVector from_to, Rcpp::NumericMatrix pts, 
 		bool keep, bool warn = true, bool authority_compliant = false) {
 
@@ -321,7 +349,7 @@ Rcpp::NumericMatrix CPL_proj_direct(Rcpp::CharacterVector from_to, Rcpp::Numeric
 	// transform:
 	if (keep) {
 		// use proj_trans() on individual points, making unprojectable points be NA
-		PJ_COORD row = { 0.0, 0.0, 0.0, 0.0 }, projected;
+		PJ_COORD row = {{ 0.0, 0.0, 0.0, 0.0 }}, projected;
 		for (int i = 0; i < pts.nrow(); i++) {
 			/*
 			row.lpzt.lam = x.data()[i].lpzt.lam;
@@ -427,7 +455,7 @@ Rcpp::CharacterVector CPL_enable_network(Rcpp::CharacterVector url, bool enable
 #endif
 }
 
-Rcpp::CharacterVector CPL_get_data_dir(bool b = false) {
+Rcpp::CharacterVector CPL_get_data_dir(bool from_proj = false) {
 #if PROJ_VERSION_MAJOR >= 7
 	return Rcpp::CharacterVector(proj_info().searchpath);
 #else
@@ -435,7 +463,7 @@ Rcpp::CharacterVector CPL_get_data_dir(bool b = false) {
 #endif
 }
 
-Rcpp::LogicalVector CPL_set_data_dir(std::string data_dir) { // #nocov start
+Rcpp::LogicalVector CPL_set_data_dir(Rcpp::CharacterVector data_dir, bool with_proj) { // #nocov start
 	return false;
 }
 
