@@ -30,29 +30,12 @@ suppressWarnings(
   sf_project("+proj=longlat", "+proj=lcc +lat_1=30 +lat_2=60", cbind(c(0,0),c(-80,-90)), keep = TRUE)
 )
 st_transform(st_sfc(st_point(c(0,0)), st_point(c(1,1)), crs = 4326), 3857)
-if (Sys.getenv("USER") %in% c("edzer", "travis")) { # causes memory leaks:
-  stopifnot(inherits(try(sf_project("+proj=longlat", "+proj=bar", matrix(1:4,2)), silent = TRUE), "try-error"))
-  stopifnot(inherits(try(sf_project("+proj=foo", "+proj=longlat", matrix(1:4,2)), silent = TRUE), "try-error"))
-}
-
 if (sf_extSoftVersion()["USE_PROJ_H"] == "true" || sf_proj_info("have_datum_files")) {
   "datum files installed"
 } else {
   "datum files not installed"
 }
 
-if (suppressPackageStartupMessages(require(sp, quietly = TRUE))) {
- x0 = sp::CRS("+init=epsg:4326")
- cat(sp::wkt(x0), "\n")
- x = st_crs(x0)
- print(x)
-
- y0 = st_crs(4326)
- y0
- y = as(y0, "CRS")
- cat(sp::wkt(y), "\n")
-}
-
 # https://github.com/r-spatial/sf/issues/1170
 g = st_as_sfc("POLYGON ((-61.66957 10.69214, -61.565 10.75728, -61.37453 10.77654, -61.40721 10.60681, -61.66957 10.69214))")
 d = st_as_sf(data.frame(id=1, geometry=g), crs=4326)
